
using System;
using System.Reflection;
using System.Collections;

namespace ServiceProvider
{

	/// <summary>
	/// Summary description for ServiceAssembly.
	/// </summary>
	/// 
	[Serializable]
	public class ServiceAssembly : System.Collections.CollectionBase
	{
		private ArrayList m_services			= new ArrayList();
		private string		m_assemblyName	= string.Empty;
		private string		m_fullName			= string.Empty;

		public ServiceAssembly() : base()
		{
		}

		public ServiceAssembly(string assemblyName) : base()
		{
			m_assemblyName = m_fullName = assemblyName;
		}

		public ServiceAssembly(string pathName, string serviceName) : base()
		{ 
			m_fullName			= pathName + "." + serviceName;
			m_assemblyName	= serviceName;
		}

		protected internal virtual Service CreateNewService(object serviceClass)
		{
			return new Service(serviceClass);
		}

		protected internal virtual void Add(Service service) 
		{
			base.InnerList.Add(service);
		}

		public void Add(object serviceClass) 
		{
			Service service = CreateNewService(serviceClass);
			Add(service);
		}

		public void Run(IServiceEventListener listener)
		{
			RunAllServices(listener);
		}

		protected virtual void RunAllServices(IServiceEventListener listener)
		{
			foreach(Service service in base.InnerList)
			{
				service.Run(listener);
			}
		}

		public Service this[int index]
		{
			get { return (Service) base.InnerList[index]; }
			set { base.InnerList[index] = value; }
		}
	}
}
